Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1093)

Unified Diff: content/browser/site_instance.cc

Issue 7064052: Revert 88142 to fix sync_integration_tests offline. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 9 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/site_instance.cc
===================================================================
--- content/browser/site_instance.cc (revision 88158)
+++ content/browser/site_instance.cc (working copy)
@@ -17,10 +17,12 @@
if (!url.is_valid())
return false;
- // We treat javascript: as the same site as any URL since it is actually
- // a modifier on existing pages.
- if (url.SchemeIs(chrome::kJavaScriptScheme))
+ // We treat javascript: and about:crash as the same site as any URL since they
+ // are actually modifiers on existing pages.
+ if (url.SchemeIs(chrome::kJavaScriptScheme) ||
+ url.spec() == chrome::kAboutCrashURL) {
return true;
+ }
return
content::GetContentClient()->browser()->IsURLSameAsAnySiteInstance(url);
« no previous file with comments | « content/browser/child_process_security_policy_unittest.cc ('k') | content/browser/site_instance_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698